Documentation
¶
Overview ¶
Package eoseenvelope provides an encoder for the EOSE (End Of Stored Events) event that signifies that a REQ has found all stored events and from here on the request morphs into a subscription, until the limit, if requested, or until CLOSE or CLOSED.
Index ¶
Constants ¶
const L = "EOSE"
L is the label associated with this type of codec.Envelope.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type T ¶
type T struct {
Subscription *subscription.Id
}
T is an EOSE envelope (End of Stored Events), that signals the end of events that are stored and the beginning of a subscription. This is necessitated by the confusing multiplexing of websockets for multiple requests, and an ugly merging of two distinct API calls, filter and subscribe.
func NewFrom ¶
func NewFrom(id *subscription.Id) *T
NewFrom creates a new eoseenvelope.T using a provided subscription.Id.
func (*T) Marshal ¶
Marshal a eoseenvelope.T envelope in minified JSON, appending to a provided destination slice.